BaseIndex

Struct BaseIndex 

#[repr(transparent)]
pub struct BaseIndex(pub NonZeroU8);
A “base index” as described in Hariguchi’s ART paper; a linearized address for a prefix/octet tuple when considering the hierarchy of possible prefixes for a given 8-bit address.

Note that this only covers up to /7, fringes (/8s) would require a ninth bit, which is encoded structurally in the trie as children (vs prefixes).

Tuple Fields

0: NonZeroU8

Implementations

Source

impl BaseIndex

pub const fn new(val: u8) -> Self

Construct a new index value.

Panics

If val is zero.

pub const fn try_new(val: u8) -> Option<Self>

Construct a new index value. Fails if the value is zero.

pub const fn get(&self) -> u8

Retrieve the value of this index in its u8 representation.

pub const fn from_prefix(octet: u8, prefix_len: u8) -> Self

Maps 8-bit prefixes to numbers. The prefixes range from 0/0 to 255/7. Return values range from 1 to 255.

Panics

If prefix_len >= 8.

pub const fn from_pfx_7(octet: u8) -> Self

Maps octet/7 prefixes to indices in 128..255. Optimization over Self::from_prefix which saves a little bit of math if the prefix length is known to be /7.

pub const fn prefix(self) -> (u8, u8)

Computes the octet and prefix len of this index. Inverse of Self::from_prefix.

pub const fn prefix_bits(&self, depth: usize) -> u8

Compute the bit position of a prefix represented by this index at a given trie depth.

pub const fn range(&self) -> RangeInclusive<u8>

Range of octets covered by this index.

This base index encodes a prefix of up to 8 bits inside a single stride (octet). This function computes the numerical start and end of the value range for that prefix.

pub const fn len(&self) -> u8

Like go’s bits.Len8: compute the number of bits required to represent this index.

pub fn cmp_rank(&self, other: &Self) -> Ordering

Sort indexes in prefix sort order.

pub const fn fmt_prefix(&self) -> impl Debug + use<>

Return a formatter for prefix notation: addr/len.

pub const fn parent(&self) -> Option<BaseIndex>

Return the direct parent of this index (if it’s not the 0/0 index).

Examples
let idx = BaseIndex::from_prefix(0, 4);
assert_eq!(idx.parent(), Some(BaseIndex::from_prefix(0, 3)));
pub const fn children(&self) -> Option<(BaseIndex, BaseIndex)>

Return the two direct children of this index (if it’s not a /7).

Examples
let idx = BaseIndex::from_prefix(0, 0);
assert_eq!(
    idx.children(),
    Some((BaseIndex::from_prefix(0, 1), BaseIndex::from_prefix(128, 1)))
);