Node

Struct Node 

pub struct Node<T, C = DefaultStorage>
where C: Storage + ?Sized,
{ pub prefixes: Array256<Vec<T>>, pub children: Array256<Vec<Child<C::Container<Self>, T>>>, }
A trie node logically covering a single (octet) address stride.

Contains prefixes (directly owned by this node) and children (descendants in the trie).

This is the canonical stride-level Node type for the crate, mirroring go-bart’s Full nodes. The operations its supports are abstracted for via the StrideOps trait – other implementations are possible, e.g. to support similar functionality to go-bart’s Lite and Fast node types.

Fields

prefixes: Array256<Vec<T>>

The prefixes this node covers directly, indexed by BaseIndex.

If this node is at trie depth 3 via octet path [192, 168] for instance, the prefix entry 12/5 => 34 would represent the overall trie route mapping 192.168.12.0/21 => 34.

children: Array256<Vec<Child<C::Container<Self>, T>>>

The children contained in this node, indexed by complete prefix octet.

Implementations

Source

impl<T, C> Node<T, C>
where C: Storage + ?Sized,

pub fn descendants( &self, include_self: bool, ) -> impl Iterator<Item = (Vec<u8, 16>, Child<&Self, &T>)>

Get all the descendant Children of this node. Order is depth-first, in-order by address.

pub fn descendant_nodes( &self, include_self: bool, ) -> impl Iterator<Item = (Vec<u8, 16>, &Self)>

Get all the descendant Nodes of this node. Order is depth-first, in-order by address.

Source

impl<T, C> Node<T, C>
where C: Storage + ?Sized,

pub const EMPTY: Self

The empty node value (no children, no prefixes).

pub const fn is_empty(&self) -> bool

Returns whether the node is empty.

pub fn stats(&self) -> Stats
where Self: StrideOps,

Return usage statistics for the trie rooted at this node.