SplitStackTable

Struct SplitStackTable 

pub struct SplitStackTable<Node> { /* private fields */ }
Routing table that segregates routes into independent IPv4 and IPv6 tables.

This is likely the kind of table you want unless you know you’ll be operating in an exclusively-single-stack environment and want to save the slight runtime overhead of discriminating on address type.

Implementations

Source

impl<T, C> SplitStackTable<Node<T, C>>
where C: ?Sized + Storage,

pub const EMPTY: Self

The empty table.

Source

impl<Node> SplitStackTable<Node>
where Node: StrideOps,

pub fn size4(&self) -> usize

Report the total number of IPv4 routes stored in the table.

pub fn size6(&self) -> usize

Report the total number of IPv6 routes stored in the table.

pub const fn root(&self, ipv4: bool) -> &Node

Get a reference to the root node for the given ip stack.