DefaultStorage

Type Alias DefaultStorage 

pub type DefaultStorage = BoxStorage;
Type alias defining the default child storage type.

This storage type is considered the best for most applications based on benchmarks and storage size profiling.

Aliased Type

pub enum DefaultStorage {}