SimpleTable

Type Alias SimpleTable 

pub type SimpleTable<T> = SimpleTable<DefaultNode<T>>;
Table for single-IP-stack environments.

Type alias around table::SimpleTable that specializes the node type to the canonical Node with boxed child storage (BoxStorage). The type parameter is the contained route value type.

Aliased Type

pub struct SimpleTable<T> { /* private fields */ }