Table

Type Alias Table 

pub type Table<T> = SplitStackTable<DefaultNode<T>>;
General-purpose table type.

Type alias around table::SplitStackTable that specializes the node type to canonical Node with boxed child storage (BoxStorage). The type parameter is the contained route value type.

Aliased Type

pub struct Table<T> { /* private fields */ }