BoxStorage

Enum BoxStorage 

pub enum BoxStorage {}
Storage that stores values in boxes.

Memory Efficiency

Vastly more memory-efficient than inline storage: heaptrack suggests on the order of 5x better.

Notably, size_of::<Box<T>>() is always a single usize, while an inline Node is 2 Array256es, which are comparatively large (256-bit bitset + vec -> ~7x larger up to alignment on a 64-bit arch). Suspect the large overhead for inline storage is mostly due to the powers-of-two oversizing of the Node::children Vec storage: this is going to be costly in direct proportion to the size of the contained value.