pub struct Node<T, C = DefaultStorage>{
pub prefixes: Array256<Vec<T>>,
pub children: Array256<Vec<Child<C::Container<Self>, T>>>,
}Expand description
A trie node logically covering a single (octet) address stride.
Contains prefixes (directly owned by this node) and children (descendants in the trie).
This is the canonical stride-level Node type for the crate, mirroring
go-bart’s Full nodes. The operations its supports are abstracted for
via the StrideOps trait – other implementations are possible, e.g. to
support similar functionality to go-bart’s Lite and Fast node types.
Fields
prefixes: Array256<Vec<T>>The prefixes this node covers directly, indexed by BaseIndex.
If this node is at trie depth 3 via octet path [192, 168] for
instance, the prefix entry 12/5 => 34 would represent the overall
trie route mapping 192.168.12.0/21 => 34.
children: Array256<Vec<Child<C::Container<Self>, T>>>The children contained in this node, indexed by complete prefix octet.
Implementations
Sourceimpl<T, C> Node<T, C>
impl<T, C> Node<T, C>