pub struct SplitStackTable<Node> { /* private fields */ }Expand description
Routing table that segregates routes into independent IPv4 and IPv6 tables.
This is likely the kind of table you want unless you know you’ll be operating in an exclusively-single-stack environment and want to save the slight runtime overhead of discriminating on address type.
Implementations
Sourceimpl<T, C> SplitStackTable<Node<T, C>>
impl<T, C> SplitStackTable<Node<T, C>>
Sourceimpl<Node> SplitStackTable<Node>where
Node: StrideOps,
impl<Node> SplitStackTable<Node>where
Node: StrideOps,