pub type DefaultStorage = BoxStorage;Expand description
Type alias defining the default child storage type.
This storage type is considered the best for most applications based on benchmarks and storage size profiling.
Aliased Type
pub enum DefaultStorage {}